
CHANGES


#### v2.0 PyPI Release


* Released on PyPI
* Added:
	* Checklists on chapter and event setup
	* More advice on events and chapter organization
	* Setup for pip installation
	* Included CoC

* Updated:
	* Sphinx
	* Sphinx/RTD theme
	* Reorganized information from original `pyladies kit <https://github.com/pyladies/pyladies-kit>`_


#### v1.0 Initial Release


Initial release of the pyladies-kit.